.. _subscribe:

=========
Subscribe
=========

DIPY_ is a part of the NiPy_ community and we are happy to share the same
e-mail list. This makes sense as we can share ideas with a broader
community and boost collaboration across neuroimagers. If you
want to post to the list you will need first to subscribe to the `nipy
mailing list`_. We suggest to begin the subject of your e-mail with
``[DIPY]``. This will help us respond faster to your questions.

Additional help can be found on the Neurostars_ website, or
on the `dipy gitter`_ channel.


.. include:: links_names.inc
